Module ast

Module ast 

RE# AST based on the regex_syntax crate.

Structs

Alternation
An alternation of regular expressions.
Assertion
A single zero-width assertion.
CaptureName
A capture name.
Comment
A comment from a regular expression with an associated span.
Complement
Concat
A concatenation of regular expressions.
Error
Flags
A group of flags.
FlagsItem
A single item in a group of flags.
Group
A grouped regular expression.
Intersection
An alternation of regular expressions.
Lookaround
An alternation of regular expressions.
Repetition
A repetition operation applied to a regular expression.
RepetitionOp
The repetition operator itself.
SetFlags
A group of flags that is not applied to a particular regular expression.
WithComments
An abstract syntax tree for a singular expression along with comments found.

Enums

AssertionKind
An assertion kind.
Ast
An abstract syntax tree for a single regular expression.
ErrorKind
The type of an error that occurred while building an AST.
Flag
A single flag.
FlagsItemKind
The kind of an item in a group of flags.
GroupKind
The kind of a group.
LookaroundKind
RepetitionKind
The kind of a repetition operator.
RepetitionRange
A range repetition operator.