Error

Struct Error 

pub struct Error { /* private fields */ }

Implementations

Source

impl Error

pub fn kind(&self) -> &ErrorKind

Return the type of this error.

pub fn pattern(&self) -> &str

The original pattern string in which this error occurred.

Every span reported by this error is reported in terms of this string.

pub fn span(&self) -> &Span

Return the span at which this error occurred.

pub fn auxiliary_span(&self) -> Option<&Span>

Return an auxiliary span. This span exists only for some errors that benefit from being able to point to two locations in the original regular expression. For example, “duplicate” errors will have the main error position set to the duplicate occurrence while its auxiliary span will be set to the initial occurrence.