RE# AST based on the regex_syntax crate.
Structs
- Alternation
- An alternation of regular expressions.
- Assertion
- A single zero-width assertion.
- Capture
Name - A capture name.
- Comment
- A comment from a regular expression with an associated span.
- Complement
- Concat
- A concatenation of regular expressions.
- Error
- Flags
- A group of flags.
- Flags
Item - A single item in a group of flags.
- Group
- A grouped regular expression.
- Intersection
- An alternation of regular expressions.
- Lookaround
- An alternation of regular expressions.
- Repetition
- A repetition operation applied to a regular expression.
- Repetition
Op - The repetition operator itself.
- SetFlags
- A group of flags that is not applied to a particular regular expression.
- With
Comments - An abstract syntax tree for a singular expression along with comments found.
Enums
- Assertion
Kind - An assertion kind.
- Ast
- An abstract syntax tree for a single regular expression.
- Error
Kind - The type of an error that occurred while building an AST.
- Flag
- A single flag.
- Flags
Item Kind - The kind of an item in a group of flags.
- Group
Kind - The kind of a group.
- Lookaround
Kind - Repetition
Kind - The kind of a repetition operator.
- Repetition
Range - A range repetition operator.